@@ -11,6 +11,7 @@ from corens.version import nsVersion, nsRelease
 from corens.vns import *
 from corens.init import *
 from corens.hylang import nsHYInit, nsHyEval, nsHyPipeline, nsHyStartup
+from corens.env import nsEnvInit
 
 
 def n(ns):
@@ -18,6 +19,7 @@ def n(ns):
 
 _lib = {
     '/bin/mkdir': nsMkdir,
+    '/bin/memory': nsMemory, 
     '/bin/get': nsGet,
     '/bin/set': nsSet,
     '/bin/ls': nsLs,
@@ -50,6 +52,7 @@ _lib = {
     '/sbin/corens_release': nsRelease,
     '/sbin/vnsinit': nsVNSinit,
     '/sbin/hyinit': nsHYInit,
+    '/sbin/envinit': nsEnvInit,
     '/sbin/init': nsInit,
     '/bin/main': nsDummyMain,
 }
